| Home | Libraries | People | FAQ | More

# Chapter 10. Root Finding & Minimization Algorithms

Several tools are provided to aid finding minima and roots of functions.

Some root-finding without derivatives methods are bisection, bracket and solve, including use of TOMS 748 algorithm.

For root-finding with derivatives the methods of Newton-Raphson iteration, Halley, and Schröder are implemented.

For locating minima of a function, a Brent minima finding example is provided.

There are several fully-worked root-finding examples, including:

- root-finding without derivatives
- root-finding with 1st derivatives
- root-finding with 1st and 2nd derivatives